@@ -6,6 +6,42 @@ package Microsoft::AdCenter::V6::ReportingService::AdGroupPerformanceReportColum
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V6::ReportingService::AdGroupPerformanceReportColumn - Represents "AdGroupPerformanceReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountName
+AccountNumber
+AdDistribution
+AdGroupId
+AdGroupName
+AverageCpc
+AverageCpm
+AveragePosition
+CampaignId
+CampaignName
+Clicks
+ConversionRate
+Conversions
+CostPerConversion
+Ctr
+CurrencyCode
+DeviceType
+Impressions
+LanguageAndRegion
+PricingModel
+Spend
+Status
+TimePeriod
+
+=cut
+
 sub AccountName {
     return 'AccountName';
 }
