@@ -6,6 +6,39 @@ package Microsoft::AdCenter::V6::ReportingService::BehavioralTargetReportColumn;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V6::ReportingService::BehavioralTargetReportColumn - Represents "BehavioralTargetReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountId
+AccountName
+AccountNumber
+AdDistribution
+AdGroupId
+AdGroupName
+AverageCpc
+AverageCpm
+AveragePosition
+BehavioralId
+CampaignId
+CampaignName
+Clicks
+Ctr
+CurrencyCode
+Impressions
+LanguageAndRegion
+PricingModel
+Spend
+TimePeriod
+
+=cut
+
 sub AccountId {
     return 'AccountId';
 }
