@@ -6,6 +6,43 @@ package Microsoft::AdCenter::V6::ReportingService::ConversionPerformanceReportCo
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V6::ReportingService::ConversionPerformanceReportColumn - Represents "ConversionPerformanceReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountId
+AccountName
+AccountNumber
+AdGroupId
+AdGroupName
+Assists
+CampaignId
+CampaignName
+Clicks
+ConversionRate
+Conversions
+CostPerAssist
+CostPerConversion
+Ctr
+ExtendedCost
+Impressions
+Keyword
+KeywordId
+ReturnOnAdSpend
+Revenue
+RevenuePerAssist
+RevenuePerConversion
+Spend
+TimePeriod
+
+=cut
+
 sub AccountId {
     return 'AccountId';
 }
