@@ -6,6 +6,41 @@ package Microsoft::AdCenter::V6::ReportingService::SearchQueryPerformanceReportC
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V6::ReportingService::SearchQueryPerformanceReportColumn - Represents "SearchQueryPerformanceReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountId
+AccountName
+AccountNumber
+AdGroupId
+AdGroupName
+AdId
+AdStatus
+AdType
+AverageCpc
+AveragePosition
+CampaignId
+CampaignName
+CampaignStatus
+Clicks
+Ctr
+DestinationUrl
+Impressions
+LanguageAndRegion
+MatchType
+SearchQuery
+Spend
+TimePeriod
+
+=cut
+
 sub AccountId {
     return 'AccountId';
 }
