@@ -6,6 +6,35 @@ package Microsoft::AdCenter::V6::ReportingService::TrafficSourcesReportColumn;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V6::ReportingService::TrafficSourcesReportColumn - Represents "TrafficSourcesReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountId
+AccountName
+AccountNumber
+Assists
+Conversions
+FunnelConversionRate
+Goal
+Revenue
+RevenuePerConversion
+Source
+Step1Count
+Step2Count
+Step3Count
+Step4Count
+Step5Count
+TimePeriod
+
+=cut
+
 sub AccountId {
     return 'AccountId';
 }
