@@ -6,6 +6,40 @@ package Microsoft::AdCenter::V7::CampaignManagementService::IncrementalBidPercen
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::CampaignManagementService::IncrementalBidPercentage - Represents "IncrementalBidPercentage" in Microsoft AdCenter Campaign Management Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+EightyPercent
+FiftyPercent
+FortyPercent
+NegativeEightyPercent
+NegativeFiftyPercent
+NegativeFortyPercent
+NegativeNinetyPercent
+NegativeOneHundredPercent
+NegativeSeventyPercent
+NegativeSixtyPercent
+NegativeTenPercent
+NegativeThirtyPercent
+NegativeTwentyPercent
+NinetyPercent
+OneHundredPercent
+SeventyPercent
+SixtyPercent
+TenPercent
+ThirtyPercent
+TwentyPercent
+ZeroPercent
+
+=cut
+
 sub EightyPercent {
     return 'EightyPercent';
 }
