@@ -6,6 +6,30 @@ package Microsoft::AdCenter::V7::CampaignManagementService::PaymentType;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::CampaignManagementService::PaymentType - Represents "PaymentType" in Microsoft AdCenter Campaign Management Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AmericanExpress
+Cash
+CashOnDelivery
+DinersClub
+DirectDebit
+Invoice
+MasterCard
+Other
+PayPal
+TravellersCheck
+Visa
+
+=cut
+
 sub AmericanExpress {
     return 'AmericanExpress';
 }
