@@ -6,6 +6,35 @@ package Microsoft::AdCenter::V7::CampaignManagementService::StandardBusinessIcon
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::CampaignManagementService::StandardBusinessIcon - Represents "StandardBusinessIcon" in Microsoft AdCenter Campaign Management Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+Accommodations
+BankOrFinanceOrCurrencyExchange
+BankOrFinanceOrCurrencyExchangeEUR
+BankOrFinanceOrCurrencyExchangeUK
+CafeOrCoffeeShop
+CarDealerOrServiceOrRental
+FlowersOrGarden
+GroceryOrDepartmentStore
+HairdresserOrBarberOrTailor
+HardwareOrRepair
+HousewaresOrRealEstateOrHomeRepair
+MoviesOrVideo
+PhonesOrServiceProvider
+PubOrBarOrLiquor
+RestaurantOrDining
+ShoppingOrBoutique
+
+=cut
+
 sub Accommodations {
     return 'Accommodations';
 }
