@@ -6,6 +6,39 @@ package Microsoft::AdCenter::V7::CustomerManagementService::Industry;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::CustomerManagementService::Industry - Represents "Industry" in Microsoft AdCenter Customer Management Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AgencySalesHouse
+Automotive
+ConsumerPackagedGoods
+Education
+Entertainment
+FinancialServices
+FoodServices
+Gaming
+GovernmentNonprofitPolitical
+Healthcare
+Internal
+NA
+Other
+PublishingAndWebMedia
+RealEstate
+Retail
+Services
+Technology
+Telecommunications
+TravelHospitality
+
+=cut
+
 sub AgencySalesHouse {
     return 'AgencySalesHouse';
 }
