@@ -6,6 +6,31 @@ package Microsoft::AdCenter::V7::CustomerManagementService::LanguageType;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::CustomerManagementService::LanguageType - Represents "LanguageType" in Microsoft AdCenter Customer Management Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+Danish
+Dutch
+English
+Finnish
+French
+German
+Italian
+Japanese
+Norwegian
+Portuguese
+Spanish
+Swedish
+
+=cut
+
 sub Danish {
     return 'Danish';
 }
