@@ -6,6 +6,29 @@ package Microsoft::AdCenter::V7::CustomerManagementService::SecretQuestion;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::CustomerManagementService::SecretQuestion - Represents "SecretQuestion" in Microsoft AdCenter Customer Management Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+Anniversary
+FatherMiddleName
+FavoriteMovie
+FavoritePetsName
+FavoriteSportsTeam
+FavoriteTeacherName
+FirstChildMiddleName
+HighSchoolName
+None
+SpouseMiddleName
+
+=cut
+
 sub Anniversary {
     return 'Anniversary';
 }
