@@ -6,6 +6,41 @@ package Microsoft::AdCenter::V7::ReportingService::AccountPerformanceReportColum
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::ReportingService::AccountPerformanceReportColumn - Represents "AccountPerformanceReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountName
+AccountNumber
+AdDistribution
+AverageCpc
+AverageCpm
+AveragePosition
+Clicks
+ConversionRate
+Conversions
+CostPerConversion
+Ctr
+CurrencyCode
+DeviceType
+Impressions
+LowQualityClicks
+LowQualityClicksPercent
+LowQualityConversionRate
+LowQualityConversions
+LowQualityImpressions
+LowQualityImpressionsPercent
+Spend
+TimePeriod
+
+=cut
+
 sub AccountName {
     return 'AccountName';
 }
