@@ -6,6 +6,45 @@ package Microsoft::AdCenter::V7::ReportingService::AdPerformanceReportColumn;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::ReportingService::AdPerformanceReportColumn - Represents "AdPerformanceReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountName
+AccountNumber
+AdDescription
+AdDistribution
+AdGroupId
+AdGroupName
+AdId
+AdTitle
+AdType
+AverageCpc
+AverageCpm
+AveragePosition
+CampaignName
+Clicks
+ConversionRate
+Conversions
+CostPerConversion
+Ctr
+CurrencyCode
+DestinationUrl
+DeviceType
+Impressions
+LanguageAndRegion
+PricingModel
+Spend
+TimePeriod
+
+=cut
+
 sub AccountName {
     return 'AccountName';
 }
