@@ -6,6 +6,31 @@ package Microsoft::AdCenter::V7::ReportingService::AgeGenderDemographicReportCol
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::ReportingService::AgeGenderDemographicReportColumn - Represents "AgeGenderDemographicReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountName
+AccountNumber
+AdDistribution
+AdGroupName
+AgeGroup
+CampaignName
+EstimatedClickPercent
+EstimatedCtr
+EstimatedImpressionPercent
+Gender
+LanguageAndRegion
+TimePeriod
+
+=cut
+
 sub AccountName {
     return 'AccountName';
 }
