@@ -6,6 +6,28 @@ package Microsoft::AdCenter::V7::ReportingService::BudgetSummaryReportColumn;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::ReportingService::BudgetSummaryReportColumn - Represents "BudgetSummaryReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountName
+AccountNumber
+CampaignName
+CurrencyCode
+DailySpend
+Date
+MonthlyBudget
+MonthToDateSpend
+ParticipationRate
+
+=cut
+
 sub AccountName {
     return 'AccountName';
 }
