@@ -6,6 +6,42 @@ package Microsoft::AdCenter::V7::ReportingService::GoalsAndFunnelsReportColumn;
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::ReportingService::GoalsAndFunnelsReportColumn - Represents "GoalsAndFunnelsReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountId
+AccountName
+AccountNumber
+AdGroupId
+AdGroupName
+Assists
+CampaignId
+CampaignName
+Conversions
+ExtendedCost
+FunnelConversionRate
+Goal
+Keyword
+KeywordId
+ReturnOnAdSpend
+Revenue
+Spend
+Step1Count
+Step2Count
+Step3Count
+Step4Count
+Step5Count
+TimePeriod
+
+=cut
+
 sub AccountId {
     return 'AccountId';
 }
