@@ -6,6 +6,36 @@ package Microsoft::AdCenter::V7::ReportingService::RichAdComponentPerformanceRep
 use strict;
 use warnings;
 
+=head1 NAME
+
+Microsoft::AdCenter::V7::ReportingService::RichAdComponentPerformanceReportColumn - Represents "RichAdComponentPerformanceReportColumn" in Microsoft AdCenter Reporting Service.
+
+=head1 SYNOPSIS
+
+See L<http://msdn.microsoft.com/en-us/library/ee730327.aspx> for documentation of the various data objects.
+
+=head1 ENUMERATION VALUES
+
+AccountName
+AccountNumber
+AdGroupId
+AdGroupName
+AdId
+AdTitle
+CampaignName
+ComponentClicks
+ComponentCTR
+ComponentDestinationURL
+ComponentNonBillableClicks
+ComponentPosition
+ComponentTitle
+ComponentTotalClicks
+ComponentType
+RichAdSubType
+TimePeriod
+
+=cut
+
 sub AccountName {
     return 'AccountName';
 }
